@@ -27,11 +27,9 @@
 
 #include <iostream>
 
-#include <glibmm/thread.h>
 #include <glibmm/i18n.h>
 #include <glibmm/stringutils.h>
 #include <glibmm/optionentry.h>
-#include <gtkmm/main.h>
 #include <gtkmm/aboutdialog.h>
 #include <gtkmm/builder.h>
 #include <gtkmm/shortcutswindow.h>
