@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2022 Aurimas Cernius
+ * Copyright (C) 2010-2023 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -119,7 +119,7 @@ namespace gnote {
 
     m_search_notes_widget = new SearchNotesWidget(g, m);
     m_search_notes_widget->signal_open_note
-      .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_open_note));
+      .connect(sigc::mem_fun(*this, &NoteRecentChanges::present_note));
     m_search_notes_widget->signal_open_note_new_window
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_open_note_new_window));
     m_search_notes_widget->notes_widget().signal_key_press_event()
@@ -150,7 +150,7 @@ namespace gnote {
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::on_key_pressed));
     g.signal_quit
       .connect(sigc::mem_fun(*this, &NoteRecentChanges::close_window));// to save size/pos
-    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
+    m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_current_tab),
                                 GDK_KEY_W, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
     m_keybinder.add_accelerator(sigc::mem_fun(*this, &NoteRecentChanges::close_window),
                                 GDK_KEY_Q, Gdk::CONTROL_MASK, (Gtk::AccelFlags)0);
@@ -489,7 +489,13 @@ namespace gnote {
 
   void NoteRecentChanges::present_note(const Note::Ptr & note)
   {
-    if(note && note->has_window()) {
+    if(!note) {
+      return;
+    }
+    if(present_active(note)) {
+      return;
+    }
+    if(note->has_window()) {
       auto win = note->get_window();
       if(win->host()) {
         win->host()->unembed_widget(*win);
@@ -518,13 +524,6 @@ namespace gnote {
   }
 
 
-  void NoteRecentChanges::on_open_note(const Note::Ptr & note)
-  {
-    if(!present_active(note)) {
-      present_note(note);
-    }
-  }
-
   void NoteRecentChanges::on_open_note_new_window(const Note::Ptr & note)
   {
     present_in_new_window(m_gnote, note);
@@ -648,6 +647,18 @@ namespace gnote {
     m_embed_book.set_current_page(prev_page);
   }
 
+  void NoteRecentChanges::close_current_tab()
+  {
+    int page_idx = m_embed_book.get_current_page();
+    if(page_idx == 0) {
+      return;
+    }
+
+    if(auto widget = dynamic_cast<EmbeddableWidget*>(m_embed_book.get_nth_page(page_idx))) {
+      unembed_widget(*widget);
+    }
+  }
+
   void NoteRecentChanges::on_show()
   {
     // Select "All Notes" in the notebooks list
@@ -684,7 +695,8 @@ namespace gnote {
       tab_label->signal_close.connect(sigc::mem_fun(*this, &NoteRecentChanges::unembed_widget));
     }
     tab_label->show();
-    int idx = m_embed_book.append_page(*win, *tab_label);
+    int idx = m_embed_book.get_current_page() + 1;
+    m_embed_book.insert_page(*win, *tab_label, idx);
     m_embed_book.set_current_page(idx);
   }
 
@@ -703,7 +715,7 @@ namespace gnote {
       return;
     }
     if(n_pages > 1 && page_to_remove == m_embed_book.get_current_page()) {
-      int new_page = (page_to_remove == n_pages - 1) ? page_to_remove - 1 : page_to_remove + 1;
+      int new_page = page_to_remove - 1;
       m_embed_book.set_current_page(new_page);
     }
 
